@@ -2,21 +2,17 @@
 # Copyright (C) 2017 The Qt Company Ltd.
 # SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
+# Allow retry in case mdutil fails with first tries
+set +e
+
 disableSpotlight() {
     # Disable spotlight and and stop indexing
-    sudo mdutil -a -i off
-    sudo mdutil -a -i off /
+    sudo mdutil -a -i off || return 1
+    sudo mdutil -a -i off / || return 1
     # Disable spotlight indexing /Volumes
-    sudo mdutil -i off /Volumes
+    sudo mdutil -i off /Volumes || return 1
     # Erase spotlight index
-    sudo mdutil -E /
-}
-
-fixUnknownIndexingState() {
-    echo "Fix unknown indexing state by enabling indexing back one by one"
-    sudo mdutil -i on / || return 1
-    sudo mdutil -i on /System/Volumes/Preboot || return 1
-    sudo mdutil -i on /System/Volumes/Data || return 1
+    sudo mdutil -E / || return 1
 }
 
 # Disabling spotlight tends to be flaky, add some retry
@@ -29,8 +25,7 @@ do
         echo "Spotlight disabled"
         break
     else
-        echo "Failed to disable spotlight, $i run fix and retry..."
-        fixUnknownIndexingState
+        echo "Failed to disable spotlight, $i retry..."
         sleep 2
     fi
 done
